<?php
/**
 * @author La clic ! <contact@laclic.fr>
 */

namespace App\DataFixtures;


use App\Entity\Config\TaxRate;
use App\Entity\Config\Unit;
use App\Entity\Merchant\Merchant;
use App\Entity\Section\Section;
use App\Entity\User\User;
use App\Entity\User\UserMerchant;
use Doctrine\Bundle\FixturesBundle\Fixture;
use Doctrine\ORM\EntityManagerInterface;
use Doctrine\Persistence\ObjectManager;
use Lc\SovBundle\Model\User\UserInterface;

class CaracoleFixtures extends Fixture
{
    protected $em;

    public function __construct(EntityManagerInterface $entityManager)
    {
        $this->em = $entityManager;
    }

    public function load(ObjectManager $manager)
    {
        $fab = $this->createUserFab();
        $gui = $this->createUserGui();
        $charly = $this->createUserCharly();

        foreach (self::$unitsArray as $unit => $unitInfos) {
            $unitEntity = new Unit();
            $unitEntity->setUnit($unitInfos['unit'])
                ->setWording($unitInfos['wording'])
                ->setWordingUnit($unitInfos['wording_unit'])
                ->setWordingShort($unitInfos['wording_short'])
                ->setCoefficient($unitInfos['coefficient'])
                ->setCreatedBy($gui)
                ->setUpdatedBy($gui);
            self::$unitsArray[$unit]['entity'] = $unitEntity;
        }
        foreach (self::$unitsArray as $unit => $unitInfos) {
            self::$unitsArray[$unit]['entity']->setUnitReference(self::$unitsArray[$unitInfos['ref']]['entity']);
            $this->em->persist(self::$unitsArray[$unit]['entity']);
        }

        $taxRate = new TaxRate();
        $taxRate->setTitle('FR Taux standard (20%)');
        $taxRate->setValue(20);

        $taxRate1 = new TaxRate();
        $taxRate1->setTitle('FR Taux réduit (10%)');
        $taxRate1->setValue(10);

        $taxRate2 = new TaxRate();
        $taxRate2->setTitle('FR Taux réduit (5.5%)');
        $taxRate2->setValue(5.5);


        $taxRate3 = new TaxRate();
        $taxRate3->setTitle('FR Taux super réduit (2.1%)');
        $taxRate3->setValue(2.1);

        $hubBelfort = new Merchant();
        $hubBelfort->setTitle('Belfort - Montbéliard');
        $hubBelfort->setTaxRate($taxRate2);

        $hubBesac = new Merchant();
        $hubBesac->setTitle('Besançon');
        $hubBesac->setTaxRate($taxRate2);

        $this->createUserMerchant($fab, $hubBelfort);
        $this->createUserMerchant($fab, $hubBesac);
        $this->createUserMerchant($gui, $hubBelfort);
        $this->createUserMerchant($gui, $hubBesac);
        $this->createUserMerchant($charly, $hubBelfort);
        $this->createUserMerchant($charly, $hubBesac);

        $this->createSessionsBesak($hubBesac, $fab);
        $this->createSectionBelfort($hubBelfort, $fab);

        $taxRate->setCreatedBy($fab)->setUpdatedBy($fab);
        $taxRate1->setCreatedBy($fab)->setUpdatedBy($fab);
        $taxRate2->setCreatedBy($fab)->setUpdatedBy($fab);
        $taxRate3->setCreatedBy($fab)->setUpdatedBy($fab);
        $hubBelfort->setCreatedBy($fab)->setUpdatedBy($fab)->setStatus(1);
        $hubBesac->setCreatedBy($fab)->setUpdatedBy($fab)->setStatus(1);

        $this->em->persist($charly);
        $this->em->persist($fab);
        $this->em->persist($gui);
        $this->em->persist($taxRate);
        $this->em->persist($taxRate1);
        $this->em->persist($taxRate2);
        $this->em->persist($taxRate3);
        $this->em->persist($hubBelfort);
        $this->em->persist($hubBesac);


        $manager->flush();
    }


    protected function createSectionBelfort($hubBelfort, $user)
    {
        $sectionBelfort[0] = new Section();
        $sectionBelfort[0]->setTitle('Marché');
        $sectionBelfort[0]->setStatus(1);
        $sectionBelfort[0]->setIsDefault(true);
        $sectionBelfort[0]->setColor('#F9DC5C');
        $sectionBelfort[0]->setCycle(Section::CYCLE_WEEK);
        $sectionBelfort[0]->setMerchant($hubBelfort);
        $sectionBelfort[0]->setCreatedBy($user)->setUpdatedBy($user);

        $sectionBelfort[1] = new Section();
        $sectionBelfort[1]->setTitle('Repas midi');
        $sectionBelfort[1]->setStatus(1);
        $sectionBelfort[1]->setColor('#ED254E');
        $sectionBelfort[1]->setCycle(Section::CYCLE_DAY);
        $sectionBelfort[1]->setMerchant($hubBelfort);
        $sectionBelfort[1]->setCreatedBy($user)->setUpdatedBy($user);


        $sectionBelfort[2] = new Section();
        $sectionBelfort[2]->setTitle('Retrait jounrée');
        $sectionBelfort[2]->setStatus(1);
        $sectionBelfort[2]->setColor('#94C9A9');
        $sectionBelfort[2]->setCycle(Section::CYCLE_DAY);
        $sectionBelfort[2]->setMerchant($hubBelfort);
        $sectionBelfort[2]->setCreatedBy($user)->setUpdatedBy($user);

        $sectionBelfort[3] = new Section();
        $sectionBelfort[3]->setTitle('Espace Pro');
        $sectionBelfort[3]->setStatus(1);
        $sectionBelfort[3]->setColor('#464655');
        $sectionBelfort[3]->setCycle(Section::CYCLE_WEEK);
        $sectionBelfort[3]->setMerchant($hubBelfort);
        $sectionBelfort[3]->setCreatedBy($user)->setUpdatedBy($user);

        $this->em->persist($sectionBelfort[0]);
        $this->em->persist($sectionBelfort[1]);
        $this->em->persist($sectionBelfort[2]);
        $this->em->persist($sectionBelfort[3]);

        return $sectionBelfort;
    }

    protected function createSessionsBesak($hubBesak, $user)
    {
        $sectionBesac = new Section();
        $sectionBesac->setTitle('Marché');
        $sectionBesac->setStatus(1);
        $sectionBesac->setIsDefault(true);

        $sectionBesac->setColor('#F9DC5C');
        $sectionBesac->setCycle(Section::CYCLE_WEEK);
        $sectionBesac->setMerchant($hubBesak);
        $sectionBesac->setCreatedBy($user)->setUpdatedBy($user);

        $this->em->persist($sectionBesac);

        return $sectionBesac;
    }

    protected function createUserFab()
    {
        $fab = new User();
        $fab->setEmail('fab@laclic.fr');
        $fab->setLastname('Normand');
        $fab->setFirstname('Fab');
        $fab->setPassword('$2y$13$ExSKxXX8bQ20fBocZrUAJugov2MfE2x14BxsQaVyODsousxPWS2gS');
        $fab->setRoles(array('ROLE_ADMIN', 'ROLE_SUPER_ADMIN'));

        return $fab;
    }

    protected function createUserGui()
    {
        $gui = new User();
        $gui->setEmail('guillaume@laclic.fr');
        $gui->setLastname('Bourgeois');
        $gui->setFirstname('Guillaume');
        $gui->setPassword('$2y$13$sGqcr64Cdhg8bRs744Ry..ub/Pi6uzpPMfBxdjCdenOXV5fFZ4TA.');

        $gui->setRoles(array('ROLE_ADMIN', 'ROLE_SUPER_ADMIN'));
        return $gui;
    }

    protected function createUserCharly()
    {
        $charly = new User();
        $charly->setEmail('charly@laclic.fr');
        $charly->setLastname('Charly');
        $charly->setFirstname('Mainier');
        $charly->setPassword('$argon2id$v=19$m=65536,t=4,p=1$5eVep168MSPP4klWgyPMrQ$1qrwInxOzS5PxNML2ZmneUeNeoAeD2o6CmZhp5iMaec');
        $charly->setRoles(array('ROLE_ADMIN', 'ROLE_SUPER_ADMIN'));
        return $charly;
    }

    public function createUserMerchant($user, $merchant)
    {
        $userMerchant = new UserMerchant();
        $userMerchant->setUser($user);
        $userMerchant->setMerchant($merchant);
        $userMerchant->setCreditActive(false);
        $userMerchant->setActive(true);
        $userMerchant->setRoles(array('ROLE_ADMIN', 'ROLE_SUPER_ADMIN'));
        $this->em->persist($userMerchant);
        return $userMerchant;
    }

    public static $unitsArray = [
        'piece' => [
            'unit' => 'piece',
            'wording_unit' => 'la pièce',
            'wording' => 'pièce(s)',
            'wording_short' => 'p.',
            'coefficient' => 1,
            'ref' => 'piece'
        ],
        'g' => [
            'unit' => 'g',
            'wording_unit' => 'le g',
            'wording' => 'g',
            'wording_short' => 'g',
            'coefficient' => 1000,
            'ref' => 'kg'
        ],
        'kg' => [
            'unit' => 'kg',
            'wording_unit' => 'le kg',
            'wording' => 'kg',
            'wording_short' => 'kg',
            'coefficient' => 1,
            'ref' => 'kg'
        ],
        'mL' => [
            'unit' => 'mL',
            'wording_unit' => 'le mL',
            'wording' => 'mL',
            'wording_short' => 'mL',
            'coefficient' => 1000,
            'ref' => 'L'
        ],
        'cL' => [
            'unit' => 'cL',
            'wording_unit' => 'le cL',
            'wording' => 'cL',
            'wording_short' => 'cL',
            'coefficient' => 100,
            'ref' => 'L'
        ],
        'L' => [
            'unit' => 'L',
            'wording_unit' => 'le litre',
            'wording' => 'L',
            'wording_short' => 'L',
            'coefficient' => 1,
            'ref' => 'L'
        ],
    ];


}